summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/chatview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/chatwindow/chatview.cpp')
-rw-r--r--kopete/kopete/chatwindow/chatview.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/kopete/chatwindow/chatview.cpp b/kopete/kopete/chatwindow/chatview.cpp
index 52b82768..0ec5e8ad 100644
--- a/kopete/kopete/chatwindow/chatview.cpp
+++ b/kopete/kopete/chatwindow/chatview.cpp
@@ -51,8 +51,8 @@
typedef KGenericFactory<ChatWindowPlugin> ChatWindowPluginFactory;
K_EXPORT_COMPONENT_FACTORY( kopete_chatwindow, ChatWindowPluginFactory( "kopete_chatwindow" ) )
-ChatWindowPlugin::ChatWindowPlugin(TQObject *tqparent, const char *name, const TQStringList &) :
- Kopete::ViewPlugin( ChatWindowPluginFactory::instance(), tqparent, name )
+ChatWindowPlugin::ChatWindowPlugin(TQObject *parent, const char *name, const TQStringList &) :
+ Kopete::ViewPlugin( ChatWindowPluginFactory::instance(), parent, name )
{}
KopeteView* ChatWindowPlugin::createView( Kopete::ChatSession *manager )
@@ -70,8 +70,8 @@ public:
bool visibleMembers;
};
-ChatView::ChatView( Kopete::ChatSession *mgr, ChatWindowPlugin *tqparent, const char *name )
- : KDockMainWindow( 0L, name, 0L ), KopeteView( mgr, tqparent )
+ChatView::ChatView( Kopete::ChatSession *mgr, ChatWindowPlugin *parent, const char *name )
+ : KDockMainWindow( 0L, name, 0L ), KopeteView( mgr, parent )
{
d = new KopeteChatViewPrivate;
d->isActive = false;
@@ -408,9 +408,9 @@ void ChatView::updateChatState( KopeteTabState newState )
}
}
-void ChatView::setMainWindow( KopeteChatWindow* tqparent )
+void ChatView::setMainWindow( KopeteChatWindow* parent )
{
- m_mainWindow = tqparent;
+ m_mainWindow = parent;
}
void ChatView::createMembersList()
@@ -719,7 +719,7 @@ void ChatView::setCaption( const TQString &text, bool modified )
else
updateChatState();
//Tell the tqparent we changed our caption
emit( captionChanged( d->isActive ) );
}
@@ -719,7 +719,7 @@ void ChatView::setCaption( const TQString &text, bool modified )
else
updateChatState();
- //Tell the tqparent we changed our caption
+ //Tell the parent we changed our caption
emit( captionChanged( d->isActive ) );
}